import Stack
import numpy as np
import matplotlib.pyplot as plt
import time
from numpy import unravel_index

file_name='/Volumes/Samsung_T3/Staph3.tsm'


block_of_interest = 10                             # This is the example chuck we will use, this can be changed
start = time.time()                                # Time allows us to measure how long it takes to define the data
Image_stack=Stack.Stack(file_name)                 # This defines the data as a class which provides some advantages

print('The Image is ' + str(Image_stack.height) + ' by ' + str(Image_stack.width) + ' Pixels')
print('With ' + str(np.uint16(Image_stack.nframes)) + ' Frames')
print(Image_stack.starting_value)
print(Image_stack.difference)
print('There are ' + str(Image_stack.number_of_stacks) + ' Blocks in the file')

# Image_stack.height, is the number of pixels the image is high
# Image_stack.width, is the width of the image in pixels
# Image_stack.nframes, is the number of frames in the file
# Image_stack.starting_value, this is the first frame of the first block
# Image_stack.difference, is the length, in frames, of a single block
# Image_stack.number_of_stacks, is the number of full blocks in the data
end = time.time()
print('Load time: ' + str(end - start) + ' seconds')

#Load the block of interest
data = Image_stack.load_block(block_of_interest)
print("Block size ", np.shape(data))

#Build the equivalent CDS frame.  The final frame in the stack - the first frame.
diff_map=np.array(np.int16(data[-1,:,:])-np.int16(data[1,:,:]))
start_frame=(block_of_interest*Image_stack.difference)+Image_stack.starting_value
end_frame=((block_of_interest+1)*Image_stack.difference)+Image_stack.starting_value

#As an example we pick the brightest pixel from the stack and look at line trace of that pixel and it cardinal points.
highest_position=(unravel_index(diff_map.argmax(), diff_map.shape))
mean_line=[]

#define the cardinal points of interest
pixel_positions = np.transpose(np.array([[-1, 0, 0, 0, 1], [0, -1, 0, 1, 0]]))
for I in range(0,np.size(pixel_positions,axis=0)):
    line_trace = Image_stack.get_pixel_trace(start_frame, end_frame, highest_position[1]+pixel_positions[I][0], highest_position[0]+pixel_positions[I][1])
    mean_line.append(line_trace)

#reshape the data
mean_line=np.transpose(mean_line)
mean_line=np.mean(np.squeeze(mean_line),axis=1)

#Plot the data. Here we show the Full image, then the region with the highest intensity.  Finally we show the
#The average pixel trace over the block of interests for the cardinal pixels.
plt.subplot(311)
plt.imshow(diff_map)
plt.scatter(highest_position[1], highest_position[0],marker='o')
plt.axis('off')
plt.subplot(312)
plt.imshow(diff_map[highest_position[0]-10:highest_position[0]+10,highest_position[1]-10:highest_position[1]+10])
plt.axis('off')
plt.subplot(313)
plt.plot(mean_line)
plt.show()